@@ -15,36 +15,47 @@ def is_installed(library):
 
 jaeger_client = 'sfx-jaeger-client>=3.13.1b0.dev5'
 
+old_instrumentors = [
+    'elasticsearch-opentracing',
+    'celery-opentracing',
+    'django-opentracing',
+    'Flask-Opentracing',
+    'dbapi-opentracing',
+    'pymongo-opentracing',
+    'dbapi-opentracing',
+    'redis-opentracing',
+    'requests-opentracing',
+    'tornado-opentracing',
+]
 
 # target library to desired instrumentor path/versioned package name
 instrumentors = {
-    'celery': 'https://github.com/signalfx/python-celery/tarball/0.0.1post0#egg=celery-opentracing',
-    'django': 'https://github.com/signalfx/python-django/tarball/0.1.18post1#egg=django-opentracing',
-    'elasticsearch': ('https://github.com/signalfx/python-elasticsearch/tarball/0.1.4post1'
-                      '#egg=elasticsearch-opentracing'),
-    'flask': 'https://github.com/signalfx/python-flask/tarball/1.1.0post1#egg=flask_opentracing',
-    'psycopg2': 'https://github.com/signalfx/python-dbapi/tarball/v0.0.5post2#egg=dbapi-opentracing',
-    'pymongo': 'https://github.com/signalfx/python-pymongo/tarball/v0.0.3post1#egg=pymongo-opentracing',
-    'pymysql': 'https://github.com/signalfx/python-dbapi/tarball/v0.0.5post2#egg=dbapi-opentracing',
-    'redis': 'https://github.com/signalfx/python-redis/tarball/v1.0.0post1#egg=redis-opentracing',
-    'requests': 'https://github.com/signalfx/python-requests/archive/v0.2.0post2.zip#egg=requests-opentracing',
-    'tornado': 'https://github.com/signalfx/python-tornado/archive/1.0.1post1.zip#egg=tornado_opentracing',
+    'celery': 'signalfx-instrumentation-celery>=1.0.0',
+    'django': 'signalfx-instrumentation-django>=1.0.0',
+    'elasticsearch': 'signalfx-instrumentation-elasticsearch>=1.0.0',
+    'flask': 'signalfx-instrumentation-flask>=1.0.0',
+    'psycopg2': 'signalfx-instrumentation-dbapi>=1.0.0',
+    'pymongo': 'signalfx-instrumentation-pymongo>=1.0.0',
+    'pymysql': 'signalfx-instrumentation-dbapi>=1.0.0',
+    'redis': 'signalfx-instrumentation-redis>=1.0.0',
+    'requests': 'signalfx-instrumentation-requests>=1.0.0',
+    'tornado': 'signalfx-instrumentation-tornado>=1.0.0',
 }
 
 # relevant instrumentors and tracers to uninstall and check for conflicts for target libraries
 packages = {
-    'celery': ('celery-opentracing',),
-    'django': ('django-opentracing',),
-    'elasticsearch': ('elasticsearch-opentracing',),
-    'flask': ('Flask-OpenTracing',),
+    'celery': ('signalfx-instrumentation-celery',),
+    'django': ('signalfx-instrumentation-django',),
+    'elasticsearch': ('signalfx-instrumentation-elasticsearch',),
+    'flask': ('signalfx-instrumentation-flask',),
     'jaeger': ('sfx-jaeger-client', 'jaeger-client'),
-    'psycopg2': ('dbapi-opentracing',),
-    'pymongo': ('pymongo-opentracing',),
-    'pymysql': ('dbapi-opentracing',),
-    'redis': ('redis-opentracing',),
-    'requests': ('requests-opentracing',),
+    'psycopg2': ('signalfx-instrumentation-dbapi',),
+    'pymongo': ('signalfx-instrumentation-pymongo',),
+    'pymysql': ('signalfx-instrumentation-dbapi',),
+    'redis': ('signalfx-instrumentation-redis',),
+    'requests': ('signalfx-instrumentation-requests',),
     'signalfx-tracing': ('signalfx-tracing',),
-    'tornado': ('tornado-opentracing',),
+    'tornado': ('signalfx-instrumentation-tornado',),
 }
 
 
@@ -74,6 +85,10 @@ def _install_updated_dependency(library, package_path, target=None):
             if '{}=='.format(package).lower() in pip_list:
                 print('Existing {} installation detected.  Uninstalling.'.format(package))
                 subprocess.check_call([sys.executable, '-m', 'pip', 'uninstall', '-y', package])
+        for package in old_instrumentors:
+            if '{}=='.format(package).lower() in pip_list:
+                print('Found deprecated instrumentor {}. Uninstalling.'.format(package))
+                subprocess.check_call([sys.executable, '-m', 'pip', 'uninstall', '-y', package])
 
     # explicit upgrade strategy to override potential pip config
     subprocess.check_call([sys.executable, '-m', 'pip', 'install', '-U',
